@@ -4,7 +4,8 @@ import zerohertzLib as zz
 
 
 def test_storage():
-    zz.monitoring.storage(".")
+    path = zz.monitoring.storage()
+    assert path.split("/")[-1] in os.listdir()
 
 
 def test_cpu():
